@@ -1,14 +1,10 @@
-class NoImporterFoundWarning(RuntimeWarning):
-    pass
-
-
-class NoReaderFoundWarning(RuntimeWarning):
-    pass
-
-
 class MetadataMissingWarning(RuntimeWarning):
     pass
 
 
 class MetadataMissingError(RuntimeError):
-    pass
\ No newline at end of file
+    pass
+
+
+class IOOperationNotFoundError(RuntimeError, ValueError):
+    pass
